﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using WebMatrix.WebData;
using System.Web.Security;

namespace TFC.Controllers
{
    public class AdministradorFincasController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();
        private string rol = "Administrador de fincas";

        //
        // GET: /AdministradorFincas/

        public ActionResult Index()
        {
            var personas = db.Personas.Include("Provincia").Include("Subcuenta");
            return View(personas.OfType<AdministradorFincas>().ToList());
        }

        //
        // GET: /AdministradorFincas/Details/5

        public ActionResult Details(int id = 0)
        {
            AdministradorFincas administradorfincas = db.Personas.OfType<AdministradorFincas>().Single(a => a.IdPersona == id);
            if (administradorfincas == null)
            {
                return HttpNotFound();
            }
            return View(administradorfincas);
        }

        //
        // GET: /AdministradorFincas/Create

        public ActionResult Create()
        {
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre");
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion");

            // Lo creamos Activo por defecto
            return View(new AdministradorFincas { Activo = true } );
        }

        //
        // POST: /AdministradorFincas/Create

        [HttpPost]
        public ActionResult Create(AdministradorFincas administradorfincas)
        {
            if (ModelState.IsValid)
            {
                db.Personas.AddObject(administradorfincas);
                db.SaveChanges();

                if (administradorfincas.Activo == true) { 
                    /* Si se crea un administrador como activo, creamos una cuenta de inicio de sesión con su email y lo 
                    * incluimos en el rol de administradores de fincas. La comprobación de si el email existe se hace 
                    * con DataAnotations en la propiedad Email de Persona en la clase TFCModel.Designer.cs. */
                    Entorno.CrearInicioSesion(administradorfincas.Email, rol);
                }
                return RedirectToAction("Index");
            }

            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", administradorfincas.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", administradorfincas.IdSubcuenta);
            return View(administradorfincas);
        }

        //
        // GET: /AdministradorFincas/Edit/5

        public ActionResult Edit(int id = 0)
        {
            AdministradorFincas administradorfincas = db.Personas.OfType<AdministradorFincas>().Single(a => a.IdPersona == id);
            if (administradorfincas == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", administradorfincas.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", administradorfincas.IdSubcuenta);
            return View(administradorfincas);
        }

        //
        // POST: /AdministradorFincas/Edit/5

        [HttpPost]
        public ActionResult Edit(AdministradorFincas administradorfincas)
        {
            
            if (ModelState.IsValid)
            {
                bool cambioActivo = false;
                bool cambioEmail = false;

                TFCEntities1 ad = new TFCEntities1();

                AdministradorFincas af = ad.Personas.OfType<AdministradorFincas>().Where(p => p.IdPersona == administradorfincas.IdPersona).Single();
               
                //Comprobamos si ha cambiado el campo Activo o el Email.
                if (af.Activo != administradorfincas.Activo)
                {
                    cambioActivo = true;
                }
                if (af.Email != administradorfincas.Email)
                {
                    cambioEmail = true;
                }
                
                db.Personas.Attach(administradorfincas);
                db.ObjectStateManager.ChangeObjectState(administradorfincas, EntityState.Modified);
                db.SaveChanges();

                if (cambioActivo == true)
                {
                    if (administradorfincas.Activo == true)
                    {
                        //Si antes era inactivo y ahora activo, creamos un inicio de sesión.
                        Entorno.CrearInicioSesion(administradorfincas.Email, rol);
                    }
                    else
                    {
                        //Si antes estaba activo y ahora no, eliminamos la cuenta de inicio de sesión del usuario.
                        Entorno.EliminarInicioSesion(af.Email, rol);
                    }
                }
                else
                {
                    if (cambioEmail == true && administradorfincas.Activo == true)
                    {
                        //Si ha habido un cambio en Email y es un usuario activo, 
                        //eliminamos la cuenta de inicio de sesión con el Email anterior,
                        Entorno.EliminarInicioSesion(af.Email, rol);

                        //y creamos una con el nuevo Email.
                        Entorno.CrearInicioSesion(administradorfincas.Email, rol);
                    }
                }
                return RedirectToAction("Index");
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", administradorfincas.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", administradorfincas.IdSubcuenta);
            return View(administradorfincas);
        }

        //
        // GET: /AdministradorFincas/Delete/5

        public ActionResult Delete(int id = 0)
        {
            AdministradorFincas administradorfincas = db.Personas.OfType<AdministradorFincas>().Single(a => a.IdPersona == id);
            if (administradorfincas == null)
            {
                return HttpNotFound();
            }
            return View(administradorfincas);
        }

        //
        // POST: /AdministradorFincas/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            var comunidades = db.Comunidades.Where(p => p.AdministradorFincasIdPersona == id).ToList();

            if (comunidades.Count == 0)
            {
                AdministradorFincas administradorfincas = db.Personas.OfType<AdministradorFincas>().Single(a => a.IdPersona == id);
                string email = administradorfincas.Email;
                db.Personas.DeleteObject(administradorfincas);
                db.SaveChanges();

                //Eliminamos el usuario de inicio de sesión
                Entorno.EliminarInicioSesion(email, rol);
                return RedirectToAction("Index");
            }
            else
            {
                return RedirectToAction("RelatedData", "Error");
            }  
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}