﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using System.IO;
using TFC.Helpers;

namespace TFC.Controllers
{
    public class BibliotecaController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Biblioteca/

        public ActionResult Index(bool privados = false)
        {
            IEnumerable<Fichero> archivos = null;
            ViewBag.Privados = privados;
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;

            if (privados == true)
            {
                // Obtenemos las comunidades del usuario conectado
                IList<Comunidad> comunidades = Datos.GetComunidades(User.Identity.Name);
                
                // Archivos privados
                if (User.IsInRole("Propietario"))
                {
                    // Si es un propietario, mostramos los archivos privados de las comunidades donde tiene alguna propiedad
                    // y que están activos a día de hoy.
                    archivos = (from co in db.Comunicaciones.OfType<Fichero>()
                                        .Include("CategoriaComunicacion")
                                        .Include("Persona")
                                join cc in db.ComunicacionesComunidades on co.IdComunicacion equals cc.IdComunicacion
                                join c in db.Comunidades on cc.IdComunidad equals c.IdComunidad
                                join p in db.Propiedades on c.IdComunidad equals p.IdComunidad
                                join pp in db.PropiedadesPropietarios on p.IdPropiedad equals pp.IdPropiedad
                                join po in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals po.IdPersona
                                where po.Email == User.Identity.Name && (co.FechaInicio <= DateTime.Today && co.FechaFin >= DateTime.Today)
                                orderby co.Fecha descending
                                select co).Distinct().ToList<Fichero>();

                    return View(archivos);
                }
                else 
                {
                    // Si es un administrador de fincas, mostramos todas los archivos privados que él ha creado.
                    archivos = from co in db.Comunicaciones.OfType<Fichero>()
                                        .Include("CategoriaComunicacion")
                               join cc in db.ComunicacionesComunidades on co.IdComunicacion equals cc.IdComunicacion
                               join c in db.Comunidades on cc.IdComunidad equals c.IdComunidad
                               join af in db.Personas.OfType<AdministradorFincas>() on c.AdministradorFincasIdPersona equals af.IdPersona
                               where af.Email == User.Identity.Name && co.Privada == true
                               orderby co.Fecha descending
                               select co;

                    return View(archivos);
                }
            }
            else
            {
                if (User.IsInRole("Propietario"))
                    // Archivos públicos. Son visibles por todos los usuarios de la aplicación.
                    archivos = from co in db.Comunicaciones.OfType<Fichero>()
                                            .Include("CategoriaComunicacion")
                               where co.Privada == false && (co.FechaInicio <= DateTime.Today && co.FechaFin >= DateTime.Today)
                               orderby co.Fecha descending
                               select co;

                    
                else {
                    //Si es un administrador, no hay limitación de fechas.
                    archivos = from co in db.Comunicaciones.OfType<Fichero>()
                                            .Include("CategoriaComunicacion")
                               where co.Privada == false 
                               orderby co.Fecha descending
                               select co;
                }
                return View(archivos);
            }    
        }

        //
        // GET: /Biblioteca/Create

        public ActionResult Create(bool privada = false)
        {
            ViewBag.Privada = privada;
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion");

            // Ponemos valores por defecto
            Fichero archivo = new Fichero { Privada = privada };

            return View();
        }

        //
        // POST: /Biblioteca/Create

        //[HttpPost]
        //public ActionResult Create(Fichero fichero)
        //{
        //    fichero.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
        //    fichero.Fecha = DateTime.Now;

        //    if (ModelState.IsValid)
        //    {
        //        db.Comunicaciones.AddObject(fichero);
        //        db.SaveChanges();
        //        return RedirectToAction("Index", new { privados = fichero.Privada });
        //    }

        //    ViewBag.Privada = fichero.Privada;
        //    ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", fichero.IdCategoria);
 
        //    return View(fichero);
        //}

        //
        // GET: /Biblioteca/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Fichero fichero = db.Comunicaciones.OfType<Fichero>().Single(f => f.IdComunicacion == id);
            if (fichero == null)
            {
                return HttpNotFound();
            }
            
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", fichero.IdCategoria);
            return View(fichero);
        }

        //
        // POST: /Biblioteca/Edit/5

        [HttpPost]
        public ActionResult Edit(Fichero fichero)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(fichero);
                db.ObjectStateManager.ChangeObjectState(fichero, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index", new { privados = fichero.Privada });
            }
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", fichero.IdCategoria);
            return View(fichero);
        }

        //
        // GET: /Biblioteca/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Fichero fichero = db.Comunicaciones.OfType<Fichero>().Single(f => f.IdComunicacion == id);
            if (fichero == null)
            {
                return HttpNotFound();
            }
            ViewBag.Privada = fichero.Privada;
            return View(fichero);
        }

        //
        // POST: /Biblioteca/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Fichero fichero = db.Comunicaciones.OfType<Fichero>().Single(f => f.IdComunicacion == id);

            bool privado = (bool)fichero.Privada;

            db.Comunicaciones.DeleteObject(fichero);
            db.SaveChanges();
            return RedirectToAction("Index", new { privados = privado });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        /// <summary>
        /// Se sube un archivo al servidor y devuelve un JSON result.
        /// </summary>
        /// <param name="file">El archivo que se quiere subir</param>
        /// <returns>FileUploadJsonResult</returns>
        /// <remarks>
        public TFC.Helpers.Util.FileUploadJsonResult AjaxUpload(HttpPostedFileBase file, Fichero fichero)
        {
            bool exito = false;
            string filename= string.Empty;
            string savedFileName = string.Empty;
            int filesize = 0;

            try
            {
                // Verificamos que el usuario ha seleccionado un archivo
                if (file != null && file.ContentLength > 0)
                {
                    filename = file.FileName;
                    filesize = file.ContentLength;

                    savedFileName = Server.MapPath(Path.Combine(@"~/uploads", Path.GetFileName(file.FileName.Replace(" ",""))));
                    //if (System.IO.File.Exists(savedFileName))
                    //{
                    //    throw new Exception(string.Format("The file '{0}' already exists on the server.", file.FileName));
                    //}

                    // almacenamos el archivo dentro de la carpeta ~/App_Data/uploads 
                    file.SaveAs(savedFileName);
                    exito = true;
                }
            }
            catch (Exception ex)
            {
                return new TFC.Helpers.Util.FileUploadJsonResult { Data = new { error = string.Format(TFC.Resources.Biblioteca.Create.SubidaFallida , ex.Message), message = string.Empty } };
            }

            if (exito == true) {

                fichero.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
                fichero.Fecha = DateTime.Now;
                fichero.NombreFichero = filename.Replace(" ", "");
                fichero.Url = savedFileName;

                if (ModelState.IsValid)
                {
                    db.Comunicaciones.AddObject(fichero);
                    db.SaveChanges();
                }
            }

            return new TFC.Helpers.Util.FileUploadJsonResult { Data = new { message = string.Format(TFC.Resources.Biblioteca.Create.Subido, Path.GetFileName(file.FileName)) } };
        }

        public ActionResult Comunidades(int id)
        {
            return RedirectToAction("Index", "ComunicacionesComunidades", new { idComunicacion = id });
        }

    }
}