﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComentariosAnunciosController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /ComentariosAnuncios/

        public ActionResult Index(int idAnuncio)
        {
            var comunicaciones = db.Comunicaciones.OfType<ComentarioAnuncio>()
                .Include("Persona").Include("CategoriaComunicacion")
                .Include("EstadoComunicacion")
                .Include("Anuncio")
                .Where(p => p.AnuncioIdComunicacion == idAnuncio);

            Anuncio anuncio = db.Comunicaciones.OfType<Anuncio>().Single(p => p.IdComunicacion == idAnuncio);

            ViewBag.AnuncioIdComunicacion = idAnuncio;
            ViewBag.Privados = anuncio.Privada;

            return View(comunicaciones.ToList());
        }

        //
        // GET: /ComentariosAnuncios/Details/5

        public ActionResult Details(int id = 0)
        {
            ComentarioAnuncio comentarioanuncio = db.Comunicaciones.OfType<ComentarioAnuncio>().Single(c => c.IdComunicacion == id);
            if (comentarioanuncio == null)
            {
                return HttpNotFound();
            }
            return View(comentarioanuncio);
        }

        //
        // GET: /ComentariosAnuncios/Create

        public ActionResult Create(int idAnuncio)
        {
            
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.AnuncioIdComunicacion = idAnuncio;
  
            return View();
        }

        //
        // POST: /ComentariosAnuncios/Create

        [HttpPost]
        public ActionResult Create(ComentarioAnuncio comentarioanuncio)
        {
            comentarioanuncio.Fecha = DateTime.Now;

            if (ModelState.IsValid)
            {
                db.Comunicaciones.AddObject(comentarioanuncio);
                db.SaveChanges();
                return RedirectToAction("Index", new { idAnuncio = comentarioanuncio.AnuncioIdComunicacion });
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.AnuncioIdComunicacion = comentarioanuncio.AnuncioIdComunicacion;
     
            return View(comentarioanuncio);
        }

        //
        // GET: /ComentariosAnuncios/Edit/5

        public ActionResult Edit(int id = 0)
        {
            ComentarioAnuncio comentarioanuncio = db.Comunicaciones.OfType<ComentarioAnuncio>().Single(c => c.IdComunicacion == id);
            if (comentarioanuncio == null)
            {
                return HttpNotFound();
            }

            ViewBag.AnuncioIdComunicacion = comentarioanuncio.AnuncioIdComunicacion;
      
            return View(comentarioanuncio);
        }

        //
        // POST: /ComentariosAnuncios/Edit/5

        [HttpPost]
        public ActionResult Edit(ComentarioAnuncio comentarioanuncio)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(comentarioanuncio);
                db.ObjectStateManager.ChangeObjectState(comentarioanuncio, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index", new { idAnuncio = comentarioanuncio.AnuncioIdComunicacion });
            }

            ViewBag.AnuncioIdComunicacion = comentarioanuncio.AnuncioIdComunicacion;
            
            return View(comentarioanuncio);
        }

        //
        // GET: /ComentariosAnuncios/Delete/5

        public ActionResult Delete(int id = 0)
        {
            ComentarioAnuncio comentarioanuncio = db.Comunicaciones.OfType<ComentarioAnuncio>().Single(c => c.IdComunicacion == id);
            if (comentarioanuncio == null)
            {
                return HttpNotFound();
            }
            return View(comentarioanuncio);
        }

        //
        // POST: /ComentariosAnuncios/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            ComentarioAnuncio comentarioanuncio = db.Comunicaciones.OfType<ComentarioAnuncio>().Single(c => c.IdComunicacion == id);
            int idCom = (int)comentarioanuncio.AnuncioIdComunicacion;
            bool privado = (bool) comentarioanuncio.Anuncio.Privada;

            db.Comunicaciones.DeleteObject(comentarioanuncio);
            db.SaveChanges();
            return RedirectToAction("Index", new { idAnuncio = idCom });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        public ActionResult Anuncios(bool privados)
        {
            return RedirectToAction("Index", "Anuncios", new { privados = privados });
        }
    }
}