﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComentariosIncidenciasController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /ComentariosIncidencias/

        public ActionResult Index(int idIncidencia)
        {
            var comunicaciones = db.Comunicaciones.OfType<ComentarioIncidencia>().Include("Persona")
                .Include("CategoriaComunicacion")
                .Include("EstadoComunicacion")
                .Include("Incidencia")
                .Where(i => i.IncidenciaIdComunicacion == idIncidencia);

            ViewBag.IncidenciaIdComunicacion = idIncidencia;
            
            return View(comunicaciones.ToList());
        }


        //
        // GET: /ComentariosIncidencias/Create

        public ActionResult Create(int idIncidencia)
        {
           
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = idIncidencia;
            return View();
        }

        //
        // POST: /ComentariosIncidencias/Create

        [HttpPost]
        public ActionResult Create(ComentarioIncidencia comentarioincidencia)
        {
            comentarioincidencia.Fecha = DateTime.Now;

            if (ModelState.IsValid)
            {
                db.Comunicaciones.AddObject(comentarioincidencia);
                db.SaveChanges();
                return RedirectToAction("Index", new { idIncidencia = comentarioincidencia.IncidenciaIdComunicacion });
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentarioincidencia.IncidenciaIdComunicacion;
            return View(comentarioincidencia);
        }

        //
        // GET: /ComentariosIncidencias/Edit/5

        public ActionResult Edit(int id = 0)
        {
            ComentarioIncidencia comentarioincidencia = db.Comunicaciones.OfType<ComentarioIncidencia>().Single(c => c.IdComunicacion == id);
            if (comentarioincidencia == null)
            {
                return HttpNotFound();
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentarioincidencia.IncidenciaIdComunicacion;
            return View(comentarioincidencia);
        }

        //
        // POST: /ComentariosIncidencias/Edit/5

        [HttpPost]
        public ActionResult Edit(ComentarioIncidencia comentarioincidencia)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(comentarioincidencia);
                db.ObjectStateManager.ChangeObjectState(comentarioincidencia, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index", new { idIncidencia = comentarioincidencia.IncidenciaIdComunicacion });
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentarioincidencia.IncidenciaIdComunicacion;
            return View(comentarioincidencia);
        }

        //
        // GET: /ComentariosIncidencias/Delete/5

        public ActionResult Delete(int id = 0)
        {
            ComentarioIncidencia comentarioincidencia = db.Comunicaciones.OfType<ComentarioIncidencia>().Single(c => c.IdComunicacion == id);
            if (comentarioincidencia == null)
            {
                return HttpNotFound();
            }
            return View(comentarioincidencia);
        }

        //
        // POST: /ComentariosIncidencias/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            ComentarioIncidencia comentarioincidencia = db.Comunicaciones.OfType<ComentarioIncidencia>().Single(c => c.IdComunicacion == id);
            int idIncid = comentarioincidencia.IncidenciaIdComunicacion;
            db.Comunicaciones.DeleteObject(comentarioincidencia);
            db.SaveChanges();
            return RedirectToAction("Index", new { idIncidencia = idIncid });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        public ActionResult Incidencias ()
        {
            return RedirectToAction("Index", "Incidencias");
        }
    }
}