﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComentariosNoticiasController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /ComentariosNoticias/

        public ActionResult Index(int idNoticia)
        {
            var comunicaciones = db.Comunicaciones.OfType<ComentarioNoticia>()
                .Include("Persona")
                .Include("CategoriaComunicacion")
                .Include("Noticia")
                .Where(p => p.NoticiaIdComunicacion == idNoticia);

            Noticia noticia = db.Comunicaciones.OfType<Noticia>().Single(p => p.IdComunicacion == idNoticia);
            ViewBag.NoticiaIdComunicacion = idNoticia;
            ViewBag.Privadas = noticia.Privada;
            return View(comunicaciones.ToList());
        }

        //
        // GET: /ComentariosNoticias/Create

        public ActionResult Create(int idNoticia)
        {

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.NoticiaIdComunicacion = idNoticia;
            return View();
        }

        //
        // POST: /ComentariosNoticias/Create

        [HttpPost]
        public ActionResult Create(ComentarioNoticia comentarionoticia)
        {
            comentarionoticia.Fecha = DateTime.Now;

            if (ModelState.IsValid)
            {
                db.Comunicaciones.AddObject(comentarionoticia);
                db.SaveChanges();
                return RedirectToAction("Index", new { idNoticia = comentarionoticia.NoticiaIdComunicacion });
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.NoticiaIdComunicacion = comentarionoticia.NoticiaIdComunicacion;
            return View(comentarionoticia);
        }

        //
        // GET: /ComentariosNoticias/Edit/5

        public ActionResult Edit(int id = 0)
        {
            ComentarioNoticia comentarionoticia = db.Comunicaciones.OfType<ComentarioNoticia>().Single(c => c.IdComunicacion == id);
            if (comentarionoticia == null)
            {
                return HttpNotFound();
            }
            
            ViewBag.NoticiaIdComunicacion = comentarionoticia.NoticiaIdComunicacion;
            return View(comentarionoticia);
        }

        //
        // POST: /ComentariosNoticias/Edit/5

        [HttpPost]
        public ActionResult Edit(ComentarioNoticia comentarionoticia)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(comentarionoticia);
                db.ObjectStateManager.ChangeObjectState(comentarionoticia, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index", new { idNoticia = comentarionoticia.NoticiaIdComunicacion });
            }

            ViewBag.NoticiaIdComunicacion = comentarionoticia.NoticiaIdComunicacion;
            return View(comentarionoticia);
        }

        //
        // GET: /ComentariosNoticias/Delete/5

        public ActionResult Delete(int id = 0)
        {
            ComentarioNoticia comentarionoticia = db.Comunicaciones.OfType<ComentarioNoticia>().Single(c => c.IdComunicacion == id);
            if (comentarionoticia == null)
            {
                return HttpNotFound();
            }
            return View(comentarionoticia);
        }

        //
        // POST: /ComentariosNoticias/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            ComentarioNoticia comentarionoticia = db.Comunicaciones.OfType<ComentarioNoticia>().Single(c => c.IdComunicacion == id);
            int idCom = (int) comentarionoticia.NoticiaIdComunicacion;
            db.Comunicaciones.DeleteObject(comentarionoticia);
            db.SaveChanges();
            return RedirectToAction("Index", new { idNoticia = idCom });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        public ActionResult Noticias(bool privadas = false)
        {
            return RedirectToAction("Index", "Noticias", new { privadas = privadas });
        }
    }
}