﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComentariosSugerenciasController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /ComentariosSugerencias/

        public ActionResult Index(int idSugerencia)
        {
            var comunicaciones = db.Comunicaciones.OfType<ComentarioSugerencia>()
                .Include("Persona")
                .Include("Sugerencia")
                .Where(p => p.SugerenciaIdComunicacion == idSugerencia);

            ViewBag.SugerenciaIdComunicacion = idSugerencia;

            return View(comunicaciones.ToList());
        }

        //
        // GET: /ComentariosSugerencias/Create

        public ActionResult Create(int idSugerencia)
        {
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.SugerenciaIdComunicacion = idSugerencia;
            return View();
        }

        //
        // POST: /ComentariosSugerencias/Create

        [HttpPost]
        public ActionResult Create(ComentarioSugerencia comentariosugerencia)
        {
            comentariosugerencia.Fecha = DateTime.Now;

            if (ModelState.IsValid)
            {
                db.Comunicaciones.AddObject(comentariosugerencia);
                db.SaveChanges();
                return RedirectToAction("Index", new { idSugerencia = comentariosugerencia.SugerenciaIdComunicacion });
            }

            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentariosugerencia.SugerenciaIdComunicacion;
            return View(comentariosugerencia);
        }

        //
        // GET: /ComentariosSugerencias/Edit/5

        public ActionResult Edit(int id = 0)
        {
            ComentarioSugerencia comentariosugerencia = db.Comunicaciones.OfType<ComentarioSugerencia>().Single(c => c.IdComunicacion == id);
            if (comentariosugerencia == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentariosugerencia.SugerenciaIdComunicacion;
            return View(comentariosugerencia);
        }

        //
        // POST: /ComentariosSugerencias/Edit/5

        [HttpPost]
        public ActionResult Edit(ComentarioSugerencia comentariosugerencia)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(comentariosugerencia);
                db.ObjectStateManager.ChangeObjectState(comentariosugerencia, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index", new { idSugerencia = comentariosugerencia.SugerenciaIdComunicacion });
            }
            ViewBag.IdPersona = Entorno.PersonaConectada(User.Identity.Name).IdPersona;
            ViewBag.IncidenciaIdComunicacion = comentariosugerencia.SugerenciaIdComunicacion;
            return View(comentariosugerencia);
        }

        //
        // GET: /ComentariosSugerencias/Delete/5

        public ActionResult Delete(int id = 0)
        {
            ComentarioSugerencia comentariosugerencia = db.Comunicaciones.OfType<ComentarioSugerencia>().Single(c => c.IdComunicacion == id);
            if (comentariosugerencia == null)
            {
                return HttpNotFound();
            }
            return View(comentariosugerencia);
        }

        //
        // POST: /ComentariosSugerencias/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            ComentarioSugerencia comentariosugerencia = db.Comunicaciones.OfType<ComentarioSugerencia>().Single(c => c.IdComunicacion == id);
            int idSug = comentariosugerencia.SugerenciaIdComunicacion;
            db.Comunicaciones.DeleteObject(comentariosugerencia);
            db.SaveChanges();
            return RedirectToAction("Index", new { idSugerencia = idSug });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        public ActionResult Sugerencias()
        {
            return RedirectToAction("Index", "Sugerencias");
        }

    }
}