﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComunicacionesComunidadesController : Controller
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /ComunicacionesComunidades/

        public ActionResult Index(int idComunicacion)
        {
            var comunicacionescomunidades = db.ComunicacionesComunidades.Include("Comunicacion").Include("Comunidad")
                .Where(p => p.IdComunicacion == idComunicacion);

            var comunicacion = db.Comunicaciones.Single(p => p.IdComunicacion == idComunicacion);

            if (comunicacion is Noticia)
            {
                Noticia n = db.Comunicaciones.OfType<Noticia>().Single(p => p.IdComunicacion == idComunicacion);

                ViewBag.IdComunicacion = idComunicacion;
                ViewBag.Titulo = n.Titulo;
                ViewBag.FechaInicio = DateTime.Parse(n.FechaInicio.ToString()).ToShortDateString();
                ViewBag.FechaFin = DateTime.Parse(n.FechaFin.ToString()).ToShortDateString();
                ViewBag.Tipo = "Noticias";
            }
            else if (comunicacion is Anuncio)
            {
                Anuncio a = db.Comunicaciones.OfType<Anuncio>().Single(p => p.IdComunicacion == idComunicacion);

                ViewBag.IdComunicacion = idComunicacion;
                ViewBag.Titulo = a.Titulo;
                ViewBag.FechaInicio = DateTime.Parse(a.FechaInicio.ToString()).ToShortDateString();
                ViewBag.FechaFin = DateTime.Parse(a.FechaFin.ToString()).ToShortDateString();
                ViewBag.Tipo = "Anuncios";
            }
            else if (comunicacion is Fichero)
            {
                Fichero a = db.Comunicaciones.OfType<Fichero>().Single(p => p.IdComunicacion == idComunicacion);

                ViewBag.IdComunicacion = idComunicacion;
                ViewBag.Titulo = a.Titulo;
                ViewBag.FechaInicio = DateTime.Parse(a.FechaInicio.ToString()).ToShortDateString();
                ViewBag.FechaFin = DateTime.Parse(a.FechaFin.ToString()).ToShortDateString();
                ViewBag.Tipo = "Ficheros";
            }
            return View(comunicacionescomunidades.ToList());
        }

        //
        // GET: /ComunicacionesComunidades/Create

        public ActionResult Create(int idComunicacion)
        {
            //Obtenemos las comunidades del usuario
            IList<Comunidad> comunidades = Datos.GetComunidades(User.Identity.Name);

            List<Comunidad> comNoAsignadas = new List<Comunidad>();

            // Recorremos la lista y nos guardamos las que no están asignadas aún a la comunicación
            foreach (Comunidad c in comunidades) 
            {

                if (db.ComunicacionesComunidades.Where(p => p.IdComunicacion == idComunicacion
                        && p.IdComunidad == c.IdComunidad).FirstOrDefault() == null)
                {
                    comNoAsignadas.Add(c);
                }  
            }

            var com = from c in comNoAsignadas
                      orderby c.Localidad, c.Direccion
                      select new
                      {
                          IdComunidad = c.IdComunidad,
                          Direccion = c.Direccion + " (" + c.Localidad + ")"
                      };


            ViewBag.Comunidades = com;
            ComunicacionComunidades cc = new ComunicacionComunidades(idComunicacion); 
            return View(cc);
        }

        //
        // POST: /ComunicacionesComunidades/Create

        [HttpPost]
        public ActionResult Create(ComunicacionComunidades comunicacioncomunidades)
        {
            if (ModelState.IsValid)
            {
                foreach(int idComunidad in comunicacioncomunidades.Comunidades){
                    ComunicacionComunidad cc = new ComunicacionComunidad();
                    cc.IdComunicacion = comunicacioncomunidades.IdComunicacion;
                    cc.IdComunidad = idComunidad;
                    db.ComunicacionesComunidades.AddObject(cc);
                }

                db.SaveChanges();
                return RedirectToAction("Index", new { idComunicacion = comunicacioncomunidades.IdComunicacion });
            }

            //Obtenemos las comunidades del usuario
            IList<Comunidad> comunidades = Datos.GetComunidades(User.Identity.Name);

            var com = from c in comunidades
                      orderby c.Localidad, c.Direccion
                      select new
                      {
                          IdComunidad = c.IdComunidad,
                          Direccion = c.Direccion + " (" + c.Localidad + ")"
                      };

            //ViewBag.IdComunicacion = comunicacioncomunidad.IdComunicacion;
            ViewBag.IdComunidad = new SelectList(com, "IdComunidad", "Direccion");
            return View(comunicacioncomunidades);
        }

        /// <summary>
        /// Comprueba si la comunicación está marcada para enviar notificaciones y, si es así,
        /// pide confirmación para enviarlas.
        /// </summary>
        /// <param name="id">Id de la comunicación</param>
        /// <returns></returns>
        public ActionResult EnviarNotificacion(int id)
        {
            List<string> destinatarios = new List<string>();

            Comunicacion com = db.Comunicaciones.Single(p => p.IdComunicacion == id);

            //Si la comunicación es una noticia y está marcada que se envíe notificación,
            //se enviarán emails a todos los propietarios con correo electrónico de las comunidades
            //asignadas a la noticia.
            if (com is Noticia)
            {
                Noticia noticia = (Noticia)com;
                if (noticia.EnviarNotificacion == true)
                {
                    //Obtenemos los identificadores de las comunidades asignadas a la noticia.
                    List<int> idComunidades = (from cc in db.ComunicacionesComunidades
                                              where cc.IdComunicacion == id
                                              select cc.IdComunidad).ToList();

                    if (idComunidades.Count > 0)
                    {
                        //Obtenemos las direcciones de email de los propietarios
                        foreach (int idCom in idComunidades)
                        {
                            List<string> emails = (from p in db.Propiedades
                                                   join pp in db.PropiedadesPropietarios on p.IdPropiedad equals pp.IdPropiedad
                                                   join pr in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals pr.IdPersona
                                                   where p.IdComunidad == idCom && pr.Email != string.Empty 
                                                   select pr.Email).ToList();

                            foreach (string email in emails)
                            {
                                destinatarios.Add(email);
                            }
                        }  
                    }
                }
            }

            ViewBag.Destinatarios = destinatarios;
            return View();
        }


        [HttpPost, ActionName("EnviarNotificacion")]
        public ActionResult EnviarNotificacionConfirmed(int id)
        {
            ComunicacionComunidad comunicacioncomunidad = db.ComunicacionesComunidades.Single(c => c.Id == id);
            int idCom = comunicacioncomunidad.IdComunicacion;
            db.ComunicacionesComunidades.DeleteObject(comunicacioncomunidad);
            db.SaveChanges();
            return RedirectToAction("Index", new { idComunicacion = idCom });
        }


        //
        // GET: /ComunicacionesComunidades/Delete/5

        public ActionResult Delete(int id = 0)
        {
            ComunicacionComunidad comunicacioncomunidad = db.ComunicacionesComunidades.Single(c => c.Id == id);
            if (comunicacioncomunidad == null)
            {
                return HttpNotFound();
            }

            ViewBag.IdComunicacion = comunicacioncomunidad.IdComunicacion;
            return View(comunicacioncomunidad);
        }

        //
        // POST: /ComunicacionesComunidades/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            
            ComunicacionComunidad comunicacioncomunidad = db.ComunicacionesComunidades.Single(c => c.Id == id);
            int idCom = comunicacioncomunidad.IdComunicacion;
            db.ComunicacionesComunidades.DeleteObject(comunicacioncomunidad);
            db.SaveChanges();
            return RedirectToAction("Index", new { idComunicacion = idCom });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

    }
}