﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Filters;
using TFC.Helpers;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComunicacionesController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Comunicaciones/

        public ActionResult SeleccionarComunidad(){


            if (User.IsInRole("Administrador de fincas"))
            {
                // Comunidades que administra el administrador de fincas
                var comunidades = from c in db.Comunidades
                                  join p in db.Personas.OfType<AdministradorFincas>() on c.AdministradorFincasIdPersona equals p.IdPersona
                                  where p.Email == User.Identity.Name
                                  select new
                                  {
                                      IdComunidad = c.IdComunidad,
                                      Nombre = c.Direccion + " (" + c.Localidad + ")"
                                  };
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Nombre");
            }
            else
            {
                // Comunidades donde el propietario tiene alguna propiedad
                var comunidades = from c in db.Comunidades
                                  join po in db.Propiedades on c.IdComunidad equals po.IdComunidad 
                                  join pp in db.PropiedadesPropietarios on po.IdPropiedad equals pp.IdPropiedad 
                                  join p in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals p.IdPersona
                                  where p.Email == User.Identity.Name
                                  select new
                                  {
                                      IdComunidad = c.IdComunidad,
                                      Nombre = c.Direccion + " (" + c.Localidad + ")"
                                  };
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Nombre");
            }

            return View();
        }

    }
}
