﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class ComunidadesController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Comunidades/

        public ActionResult Index()
        {
            // Obtenemos el administrador de fincas que está conectado 
            AdministradorFincas admin = db.Personas.OfType<AdministradorFincas>().Where(p => p.Email == User.Identity.Name).First();

            // Filtramos las comunidades pertenecientes al administrador
            var comunidades = db.Comunidades.Include("Provincia").Include("TipoPeriodo").Include("AdministradorFincas")
                .Where(p => p.AdministradorFincasIdPersona == admin.IdPersona);

            return View(comunidades.ToList());
        }

        //
        // GET: /Comunidades/Create

        public ActionResult Create()
        {
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre");
            ViewBag.IdTipoPeriodo = new SelectList(db.TiposPeriodo, "IdTipoPeriodo", "Descripcion");
            ViewBag.AdministradorFincasIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre");
            return View(new Comunidad { Activa = true });
        }

        //
        // POST: /Comunidades/Create

        [HttpPost]
        public ActionResult Create(Comunidad comunidad)
        {
            
            // Obtenemos el administrador de fincas que está conectado para asignarle la comunidad creada
            AdministradorFincas admin = db.Personas.OfType<AdministradorFincas>().Where(p => p.Email == User.Identity.Name).First();

            comunidad.AdministradorFincas = admin;

            if (ModelState.IsValid)
            {
                db.Comunidades.AddObject(comunidad);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", comunidad.IdProvincia);
            ViewBag.IdTipoPeriodo = new SelectList(db.TiposPeriodo, "IdTipoPeriodo", "Descripcion", comunidad.IdTipoPeriodo);
            ViewBag.AdministradorFincasIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", comunidad.AdministradorFincasIdPersona);
            return View(comunidad);
        }

        //
        // GET: /Comunidades/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == id);
            if (comunidad == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", comunidad.IdProvincia);
            ViewBag.IdTipoPeriodo = new SelectList(db.TiposPeriodo, "IdTipoPeriodo", "Descripcion", comunidad.IdTipoPeriodo);
            ViewBag.AdministradorFincasIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", comunidad.AdministradorFincasIdPersona);
            return View(comunidad);
        }

        //
        // POST: /Comunidades/Edit/5

        [HttpPost]
        public ActionResult Edit(Comunidad comunidad)
        {
            if (ModelState.IsValid)
            {
                db.Comunidades.Attach(comunidad);
                db.ObjectStateManager.ChangeObjectState(comunidad, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", comunidad.IdProvincia);
            ViewBag.IdTipoPeriodo = new SelectList(db.TiposPeriodo, "IdTipoPeriodo", "Descripcion", comunidad.IdTipoPeriodo);
            ViewBag.AdministradorFincasIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", comunidad.AdministradorFincasIdPersona);
            return View(comunidad);
        }

        //
        // GET: /Comunidades/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == id);
            if (comunidad == null)
            {
                return HttpNotFound();
            }
            return View(comunidad);
        }

        //
        // POST: /Comunidades/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == id);
            db.Comunidades.DeleteObject(comunidad);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }


        public ActionResult Propiedades (int id)
        {
            return RedirectToAction("Comunidad", "Propiedades", new { idComunidad = id });
        }
    }
}