﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class CuentasController : Controller
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Cuentas/

        public ActionResult Index()
        {
            var cuentas = db.Cuentas.Include("Grupos");
            return View(cuentas.ToList());
        }

        //
        // GET: /Cuentas/Details/5

        public ActionResult Details(int id = 0)
        {
            Cuenta cuenta = db.Cuentas.Single(c => c.IdCuenta == id);
            if (cuenta == null)
            {
                return HttpNotFound();
            }
            return View(cuenta);
        }

        //
        // GET: /Cuentas/Create

        public ActionResult Create()
        {
            ViewBag.IdGrupo = new SelectList(db.Grupos, "IdGrupo", "Descripcion");
            return View();
        }

        //
        // POST: /Cuentas/Create

        [HttpPost]
        public ActionResult Create(Cuenta cuenta)
        {
            if (ModelState.IsValid)
            {
                db.Cuentas.AddObject(cuenta);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.IdGrupo = new SelectList(db.Grupos, "IdGrupo", "Descripcion", cuenta.IdGrupo);
            return View(cuenta);
        }

        //
        // GET: /Cuentas/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Cuenta cuenta = db.Cuentas.Single(c => c.IdCuenta == id);
            if (cuenta == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdGrupo = new SelectList(db.Grupos, "IdGrupo", "Descripcion", cuenta.IdGrupo);
            return View(cuenta);
        }

        //
        // POST: /Cuentas/Edit/5

        [HttpPost]
        public ActionResult Edit(Cuenta cuenta)
        {
            if (ModelState.IsValid)
            {
                db.Cuentas.Attach(cuenta);
                db.ObjectStateManager.ChangeObjectState(cuenta, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdGrupo = new SelectList(db.Grupos, "IdGrupo", "Descripcion", cuenta.IdGrupo);
            return View(cuenta);
        }

        //
        // GET: /Cuentas/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Cuenta cuenta = db.Cuentas.Single(c => c.IdCuenta == id);
            if (cuenta == null)
            {
                return HttpNotFound();
            }
            return View(cuenta);
        }

        //
        // POST: /Cuentas/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Cuenta cuenta = db.Cuentas.Single(c => c.IdCuenta == id);
            db.Cuentas.DeleteObject(cuenta);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}