﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using System.Threading;

namespace TFC.Controllers
{
    public class EjerciciosCargosController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /EjerciciosCargos/

        public ActionResult Index()
        {

            var ejercicioscargo = db.EjerciciosCargo.Include("Cargo").Include("Comunidad").Include("Propietario");
            return View(ejercicioscargo.ToList());
        }

        //
        // GET: /EjerciciosCargos/Create

        public ActionResult Create()
        {
            this.GetComunidades();
            ViewBag.IdCargo = new SelectList(db.Cargos, "IdCargo", "CargoDesc");
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre");
            return View();
        }

        //
        // POST: /EjerciciosCargos/Create

        [HttpPost]
        public ActionResult Create(EjercicioCargo ejerciciocargo)
        {
            if (ModelState.IsValid)
            {
                db.EjerciciosCargo.AddObject(ejerciciocargo);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            this.GetComunidades(ejerciciocargo.IdComunidad);
            ViewBag.IdCargo = new SelectList(db.Cargos, "IdCargo", "CargoDesc", ejerciciocargo.IdCargo);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", ejerciciocargo.PropietarioIdPersona);
            return View(ejerciciocargo);
        }

        //
        // GET: /EjerciciosCargos/Edit/5

        public ActionResult Edit(int id = 0)
        {
            EjercicioCargo ejerciciocargo = db.EjerciciosCargo.Single(e => e.IdEjercicio == id);
            if (ejerciciocargo == null)
            {
                return HttpNotFound();
            }
            this.GetComunidades(ejerciciocargo.IdComunidad);
            ViewBag.IdCargo = new SelectList(db.Cargos, "IdCargo", "CargoDesc", ejerciciocargo.IdCargo);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", ejerciciocargo.PropietarioIdPersona);
            return View(ejerciciocargo);
        }

        //
        // POST: /EjerciciosCargos/Edit/5

        [HttpPost]
        public ActionResult Edit(EjercicioCargo ejerciciocargo)
        {
            if (ModelState.IsValid)
            {
                db.EjerciciosCargo.Attach(ejerciciocargo);
                db.ObjectStateManager.ChangeObjectState(ejerciciocargo, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            this.GetComunidades(ejerciciocargo.IdComunidad);
            ViewBag.IdCargo = new SelectList(db.Cargos, "IdCargo", "CargoDesc", ejerciciocargo.IdCargo);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", ejerciciocargo.PropietarioIdPersona);
            return View(ejerciciocargo);
        }

        //
        // GET: /EjerciciosCargos/Delete/5

        public ActionResult Delete(int id = 0)
        {
            EjercicioCargo ejerciciocargo = db.EjerciciosCargo.Single(e => e.IdEjercicio == id);
            if (ejerciciocargo == null)
            {
                return HttpNotFound();
            }
            return View(ejerciciocargo);
        }

        //
        // POST: /EjerciciosCargos/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            EjercicioCargo ejerciciocargo = db.EjerciciosCargo.Single(e => e.IdEjercicio == id);
            db.EjerciciosCargo.DeleteObject(ejerciciocargo);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        private void GetComunidades(int idComunidad = 0)
        {
            // Obtenemos las comunidades a las que tiene acceso el usuario conectado.
            IList<Comunidad> listaComunidades = Datos.GetComunidades(User.Identity.Name);
            var comunidades = from c in listaComunidades
                              orderby c.Localidad, c.Direccion
                              select new
                              {
                                  IdComunidad = c.IdComunidad,
                                  Direccion = c.Direccion + " (" + c.Localidad + ")"
                              };

            if (idComunidad > 0)
            {
                //Si el parámetro opcional idComunidad tiene valor, se lo asociamos a la lista como valor seleccionado por defecto.
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion", idComunidad);
            }
            else
            {
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion");
            }
        }

        //private void GetPropietarios(int idPropietario = 0)
        //{
        //    // Obtenemos las comunidades a las que tiene acceso el usuario conectado.
        //    IList<Comunidad> listaComunidades = Datos.GetComunidades(User.Identity.Name);
        //    var comunidades = from c in listaComunidades
        //                      orderby c.Localidad, c.Direccion
        //                      select new
        //                      {
        //                          IdComunidad = c.IdComunidad,
        //                          Direccion = c.Direccion + " (" + c.Localidad + ")"
        //                      };

        //    if (idComunidad > 0)
        //    {
        //        //Si el parámetro opcional idComunidad tiene valor, se lo asociamos a la lista como valor seleccionado por defecto.
        //        ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion", idComunidad);
        //    }
        //    else
        //    {
        //        ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion");
        //    }
        //}

        [HttpPost]
        public ActionResult GetPropietarios(int idComunidad)
        {
            Comunidad comunidad = db.Comunidades.Single(p => p.IdComunidad == idComunidad);
       
            IEnumerable<Propietario> propietarios = Datos.GetPropietarios(idComunidad);
            var prop = from p in propietarios
                       select new
                       {
                           IdPersona = p.IdPersona.ToString(),
                           Nombre = p.Nombre + " " + p.Apellidos
                       };

            Thread.Sleep(1000); // Simulamos tiempo de proceso...

            return Json(new SelectList(prop, "IdPersona", "Nombre")); 
        }

    }
}