﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class NotificacionesController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Notificaciones/

        public ActionResult Index()
        {
            var comunicaciones = db.Comunicaciones.OfType<Notificacion>().Include("Persona").Include("CategoriaComunicacion").Include("EstadoComunicacion");
            return View(comunicaciones.ToList());
        }

        //
        // GET: /Notificaciones/Details/5

        public ActionResult Details(int id = 0)
        {
            Notificacion notificacion = db.Comunicaciones.OfType<Notificacion>().Single(n => n.IdComunicacion == id);
            if (notificacion == null)
            {
                return HttpNotFound();
            }
            return View(notificacion);
        }

        //
        // GET: /Notificaciones/Create

        public ActionResult Create()
        {
            ViewBag.IdPersona = new SelectList(db.Personas, "IdPersona", "Nombre");
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion");
            ViewBag.IdEstado = new SelectList(db.EstadosComunicacion, "IdEstado", "Descripcion");
            return View();
        }

        //
        // POST: /Notificaciones/Create

        [HttpPost]
        public ActionResult Create(Notificacion notificacion)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.AddObject(notificacion);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.IdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", notificacion.IdPersona);
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", notificacion.IdCategoria);
            ViewBag.IdEstado = new SelectList(db.EstadosComunicacion, "IdEstado", "Descripcion", notificacion.IdEstado);
            return View(notificacion);
        }

        //
        // GET: /Notificaciones/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Notificacion notificacion = db.Comunicaciones.OfType<Notificacion>().Single(n => n.IdComunicacion == id);
            if (notificacion == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", notificacion.IdPersona);
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", notificacion.IdCategoria);
            ViewBag.IdEstado = new SelectList(db.EstadosComunicacion, "IdEstado", "Descripcion", notificacion.IdEstado);
            return View(notificacion);
        }

        //
        // POST: /Notificaciones/Edit/5

        [HttpPost]
        public ActionResult Edit(Notificacion notificacion)
        {
            if (ModelState.IsValid)
            {
                db.Comunicaciones.Attach(notificacion);
                db.ObjectStateManager.ChangeObjectState(notificacion, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", notificacion.IdPersona);
            ViewBag.IdCategoria = new SelectList(db.CategoriasComunicacion, "IdCategoria", "Descripcion", notificacion.IdCategoria);
            ViewBag.IdEstado = new SelectList(db.EstadosComunicacion, "IdEstado", "Descripcion", notificacion.IdEstado);
            return View(notificacion);
        }

        //
        // GET: /Notificaciones/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Notificacion notificacion = db.Comunicaciones.OfType<Notificacion>().Single(n => n.IdComunicacion == id);
            if (notificacion == null)
            {
                return HttpNotFound();
            }
            return View(notificacion);
        }

        //
        // POST: /Notificaciones/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Notificacion notificacion = db.Comunicaciones.OfType<Notificacion>().Single(n => n.IdComunicacion == id);
            db.Comunicaciones.DeleteObject(notificacion);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}