﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using TFC.Helpers;

namespace TFC.Controllers
{
    public class PaisesController : BaseController
    {
        private const string MODULO = "DatosMaestros";
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Paises/

        public ActionResult Index()
        {
            List<MenuItem> items = GetMenu(MODULO);

            ViewBag.MenuItems = items;
            return View(db.Paises.ToList());
        }

        //
        // GET: /Paises/Details/5

        public ActionResult Details(int id = 0)
        {
            Pais pais = db.Paises.Single(p => p.IdPais == id);
            if (pais == null)
            {
                return HttpNotFound();
            }
            return View(pais);
        }

        //
        // GET: /Paises/Create

        public ActionResult Create()
        {
            return View();
        }

        //
        // POST: /Paises/Create

        [HttpPost]
        public ActionResult Create(Pais pais)
        {
            if (ModelState.IsValid)
            {
                db.Paises.AddObject(pais);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            return View(pais);
        }

        //
        // GET: /Paises/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Pais pais = db.Paises.Single(p => p.IdPais == id);
            if (pais == null)
            {
                return HttpNotFound();
            }
            return View(pais);
        }

        //
        // POST: /Paises/Edit/5

        [HttpPost]
        public ActionResult Edit(Pais pais)
        {
            if (ModelState.IsValid)
            {
                db.Paises.Attach(pais);
                db.ObjectStateManager.ChangeObjectState(pais, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(pais);
        }

        //
        // GET: /Paises/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Pais pais = db.Paises.Single(p => p.IdPais == id);
            if (pais == null)
            {
                return HttpNotFound();
            }
            return View(pais);
        }

        //
        // POST: /Paises/Delete/5
        [HandleError]
        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            //Comprobamos si el país a borrar tiene provincias asociadas.
            //Si es así, no se permite la eliminación.
            var provincias = db.Provincias.Where(p => p.IdPais == id).ToList();
            if (provincias.Count == 0)
            {
                Pais pais = db.Paises.Single(p => p.IdPais == id);
                db.Paises.DeleteObject(pais);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            else
            {
                return RedirectToAction("RelatedData", "Error");
            }
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}