﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class PropiedadesController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Propiedades/

        public ActionResult Index()
        {
            var propiedades = db.Propiedades.Include("TipoPropiedad");
            return View(propiedades.ToList());
        }

        //
        // GET: /Propiedades/Create

        public ActionResult Create(int idComunidad)
        {
            ViewBag.IdTipo = new SelectList(db.TiposPropiedad, "IdTipo", "Tipo");
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == idComunidad);
            ViewBag.IdComunidad = idComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View();
        }

        //
        // POST: /Propiedades/Create

        [HttpPost]
        public ActionResult Create(Propiedad propiedad)
        {
            if (ModelState.IsValid)
            {
                db.Propiedades.AddObject(propiedad);
                db.SaveChanges();
                return RedirectToAction("Comunidad", new { idComunidad = propiedad.IdComunidad });
            }

            ViewBag.IdTipo = new SelectList(db.TiposPropiedad, "IdTipo", "Tipo", propiedad.IdTipo);
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View(propiedad);
        }

        //
        // GET: /Propiedades/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            if (propiedad == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdTipo = new SelectList(db.TiposPropiedad, "IdTipo", "Tipo", propiedad.IdTipo);
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View(propiedad);
        }

        //
        // POST: /Propiedades/Edit/5

        [HttpPost]
        public ActionResult Edit(Propiedad propiedad)
        {
            if (ModelState.IsValid)
            {
                db.Propiedades.Attach(propiedad);
                db.ObjectStateManager.ChangeObjectState(propiedad, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Comunidad", new { idComunidad = propiedad.IdComunidad });
            }
            ViewBag.IdTipo = new SelectList(db.TiposPropiedad, "IdTipo", "Tipo", propiedad.IdTipo);
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View(propiedad);
        }

        //
        // GET: /Propiedades/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            if (propiedad == null)
            {
                return HttpNotFound();
            }
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View(propiedad);
        }

        //
        // POST: /Propiedades/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            db.Propiedades.DeleteObject(propiedad);
            db.SaveChanges();

            return RedirectToAction("Comunidad", new { idComunidad = propiedad.IdComunidad });
        }

        public ActionResult Desasignar(int id, int idPropietario)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            PropiedadPropietario propiedadpropietario = db.PropiedadesPropietarios.Single(p => p.IdPropiedad == id && p.PropietarioIdPersona == idPropietario);
            if (propiedadpropietario == null)
            {
                return HttpNotFound();
            }

            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;

            return View(propiedadpropietario);

        }

        //
        // POST: /Propiedades/Delete/5

        [HttpPost, ActionName("Desasignar")]
        public ActionResult DesasignarConfirmed(int id, int idPropietario)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            PropiedadPropietario propiedadpropietario = db.PropiedadesPropietarios.Single(p => p.IdPropiedad == id && p.PropietarioIdPersona == idPropietario);
            db.PropiedadesPropietarios.DeleteObject(propiedadpropietario);
            db.SaveChanges();

            return RedirectToAction("Comunidad", new { idComunidad = propiedad.IdComunidad });
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        /// <summary>
        /// Muestra las propiedades de una comunidad en particular
        /// </summary>
        /// <param name="idComunidad"></param>
        /// <returns></returns>
        public ActionResult Comunidad(int idComunidad)
        {
            //Filtramos las propiedades
            var propiedades = db.Propiedades.Include("TipoPropiedad")
                .Where(c => c.IdComunidad == idComunidad);

            //Obtenemos los datos de la comunidad
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == idComunidad);
            ViewBag.IdComunidad = idComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            return View(propiedades.ToList());
        }

        // Muestra los propietarios de una propiedad
        public ActionResult Propietarios(int id)
        {
            IEnumerable<PropietariosPropiedad> propietarios = from po in db.Personas
                               join pp in db.PropiedadesPropietarios on new { IdPersona = po.IdPersona } equals new { IdPersona = pp.PropietarioIdPersona }
                               join pd in db.Propiedades on pp.IdPropiedad equals pd.IdPropiedad
                               where
                                   pp.IdPropiedad == id
                               select new PropietariosPropiedad
                               {
                                   IdPersona = po.IdPersona,
                                   Nombre = po.Nombre,
                                   Apellidos = po.Apellidos,
                                   Direccion = po.Direccion,
                                   Localidad = po.Localidad,
                                   Movil = po.Movil,
                                   Email = po.Email,
                                   Porcentaje = pp.Porcentaje
                               };

            ViewBag.IdPropiedad = id;
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == id);
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            ViewBag.PropiedadDesc = propiedad.PropiedadDesc;
            ViewBag.TipoPropiedad = propiedad.TipoPropiedad.Tipo;

            return View(propietarios);
        }

        public ActionResult AsignarPropietario(int id)
        {
            return RedirectToAction("AsignarPropietario", "PropiedadesPropietarios", new { idPropiedad = id });
        }

        public ActionResult EditPropietario(int idPropietario)
        {
            return RedirectToAction("Edit", "Propietario", new { id = idPropietario });
        }
        
    }
}