﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;

namespace TFC.Controllers
{
    public class PropiedadesPropietariosController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /PropiedadesPropietarios/

        public ActionResult Index(int idComunidad = 0)
        {
            if (idComunidad != 0)
            {
                return RedirectToAction("Comunidad", "Propiedades", new { idComunidad = idComunidad });
            }
            else { 
                var propiedadespropietarios = db.PropiedadesPropietarios.Include("Propiedad").Include("Propietario");
                return View(propiedadespropietarios.ToList());
            }
        }

        //
        // GET: /PropiedadesPropietarios/Create

        public ActionResult Create()
        {
            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc");
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre");
            return View(new PropiedadPropietario { Porcentaje = 100 });
        }

        //
        // POST: /PropiedadesPropietarios/Create

        [HttpPost]
        public ActionResult Create(PropiedadPropietario propiedadpropietario)
        {
            if (ModelState.IsValid)
            {
                db.PropiedadesPropietarios.AddObject(propiedadpropietario);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", propiedadpropietario.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", propiedadpropietario.PropietarioIdPersona);
            return View(propiedadpropietario);
        }

        //
        // GET: /PropiedadesPropietarios/Edit/5

        public ActionResult Edit(int id = 0)
        {
            PropiedadPropietario propiedadpropietario = db.PropiedadesPropietarios.Single(p => p.Id == id);
            if (propiedadpropietario == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", propiedadpropietario.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", propiedadpropietario.PropietarioIdPersona);
            return View(propiedadpropietario);
        }

        //
        // POST: /PropiedadesPropietarios/Edit/5

        [HttpPost]
        public ActionResult Edit(PropiedadPropietario propiedadpropietario)
        {
            if (ModelState.IsValid)
            {
                db.PropiedadesPropietarios.Attach(propiedadpropietario);
                db.ObjectStateManager.ChangeObjectState(propiedadpropietario, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", propiedadpropietario.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", propiedadpropietario.PropietarioIdPersona);
            return View(propiedadpropietario);
        }

        //
        // GET: /PropiedadesPropietarios/Delete/5

        public ActionResult Delete(int idPropiedad, int idPropietario)
        {
            PropiedadPropietario propiedadpropietario = db.PropiedadesPropietarios.Single(p => p.IdPropiedad == idPropiedad && p.PropietarioIdPersona == idPropietario);
            if (propiedadpropietario == null)
            {
                return HttpNotFound();
            }
            return View(propiedadpropietario);
        }

        //
        // POST: /PropiedadesPropietarios/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int idPropiedad, int idPropietario)
        {
            PropiedadPropietario propiedadpropietario = db.PropiedadesPropietarios.Single(p => p.IdPropiedad == idPropiedad && p.PropietarioIdPersona == idPropietario);
            db.PropiedadesPropietarios.DeleteObject(propiedadpropietario);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="idPropiedad"></param>
        /// <returns></returns>
        public ActionResult AsignarPropietario(int idPropiedad)
        {
            Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == idPropiedad);
            Comunidad comunidad = db.Comunidades.Single(c => c.IdComunidad == propiedad.IdComunidad);
            ViewBag.IdComunidad = propiedad.IdComunidad;
            ViewBag.NombreComunidad = comunidad.Direccion + " - " + comunidad.Localidad;
            ViewBag.PropiedadDesc = propiedad.PropiedadDesc;
            ViewBag.TipoPropiedad = propiedad.TipoPropiedad.Tipo;

            //Obtenemos los propietarios activos
            var propietarios = from p in db.Personas.OfType<Propietario>()   
                           where p.Activo == true 
                           orderby 2 
                           select new
                           {
                               IdPersona = p.IdPersona,
                               Nombre = p.Nombre + " " + (p.Apellidos == null ? "" : p.Apellidos) + " (DNI: " + (p.Nif == null ? "" : p.Nif) + ")"
                           };

            ViewBag.PropietarioIdPersona = new SelectList(propietarios, "IdPersona", "Nombre");

            return View(new PropiedadPropietario { Porcentaje = 100 });
        }

        [HttpPost]
        public ActionResult AsignarPropietario (PropiedadPropietario propiedadpropietario)
        {
            if (ModelState.IsValid)
            {
                Propiedad propiedad = db.Propiedades.Single(p => p.IdPropiedad == propiedadpropietario.IdPropiedad);
                db.PropiedadesPropietarios.AddObject(propiedadpropietario);
                db.SaveChanges();
                return RedirectToAction("Comunidad", "Propiedades", new { idComunidad = propiedad.IdComunidad });
            }

            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", propiedadpropietario.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", propiedadpropietario.PropietarioIdPersona);
            return View(propiedadpropietario);
        }
    }
}