﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using WebMatrix.WebData;
using TFC.Filters;
using System.Web.Security;

namespace TFC.Controllers
{
    public class PropietarioController : BaseController
    {
        private TFCEntities1 db = new TFCEntities1();
        private string rol = "Propietario";

        //
        // GET: /Propietario/

        public ActionResult Index()
        {
            var personas = db.Personas.OfType<Propietario>().Include("Provincia").Include("Subcuenta").Include("FormaCobro");
            return View(personas.ToList());
        }

        //
        // GET: /Propietario/Details/5

        public ActionResult Details(int id = 0)
        {
            Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == id);
            if (propietario == null)
            {
                return HttpNotFound();
            }
            return View(propietario);
        }

        //
        // GET: /Propietario/Create

        public ActionResult Create()
        {
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre");
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion");
            ViewBag.FormaCobroIdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc");

            // Lo creamos Activo por defecto
            return View(new Propietario { Activo = true });
        }

        //
        // POST: /Propietario/Create
       
        [HttpPost]
        public ActionResult Create(Propietario propietario)
        {
            if (ModelState.IsValid)
            {
                db.Personas.AddObject(propietario);
                db.SaveChanges();
                
                if (propietario.Activo == true)
                {
                    /* Si se crea un propietario como activo, creamos una cuenta de inicio de sesión con su email y lo 
                    * incluimos en el rol de propietarios. La comprobación de si el email existe se hace 
                    * con DataAnotations en la propiedad Email de Persona en la clase TFCModel.Designer.cs. */
                    if (propietario.Email != null && propietario.Email != string.Empty)
                    {
                        Entorno.CrearInicioSesion(propietario.Email, rol);
                    }
                }

                return RedirectToAction("Index");
            }

            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", propietario.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", propietario.IdSubcuenta);
            ViewBag.FormaCobroIdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", propietario.FormaCobroIdFormaCobro);
            return View(propietario);
        }

        //
        // GET: /Propietario/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == id);
            if (propietario == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", propietario.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", propietario.IdSubcuenta);
            ViewBag.FormaCobroIdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", propietario.FormaCobroIdFormaCobro);
            return View(propietario);
        }

        //
        // POST: /Propietario/Edit/5

        [HttpPost]
        public ActionResult Edit(Propietario propietario)
        {
            if (ModelState.IsValid)
            {
                bool cambioActivo = false;
                bool cambioEmail = false;

                TFCEntities1 ad = new TFCEntities1();

                Propietario pro = ad.Personas.OfType<Propietario>().Where(p => p.IdPersona == propietario.IdPersona).Single();

                //Comprobamos si ha cambiado el campo Activo o el Email.
                if (pro.Activo != propietario.Activo)
                {
                    cambioActivo = true;
                }
                if (pro.Email != propietario.Email)
                {
                    cambioEmail = true;
                }

                db.Personas.Attach(propietario);
                db.ObjectStateManager.ChangeObjectState(propietario, EntityState.Modified);
                db.SaveChanges();

                if (cambioActivo == true)
                {
                    if (propietario.Activo == true)
                    {
                        //Si antes era inactivo y ahora activo, creamos un inicio de sesión.
                        if (propietario.Email != null && propietario.Email != string.Empty)
                        {
                            Entorno.CrearInicioSesion(propietario.Email, rol);
                        }
                    }
                    else
                    {
                        //Si antes estaba activo y ahora no, eliminamos la cuenta de inicio de sesión del usuario.
                        if (pro.Email != null && pro.Email != string.Empty)
                        {
                            Entorno.EliminarInicioSesion(pro.Email, rol);
                        }
                    }
                }
                else
                {
                    if (cambioEmail == true && propietario.Activo == true)
                    {
                        //Si ha habido un cambio en Email y es un usuario activo, 
                        //eliminamos la cuenta de inicio de sesión con el Email anterior,
                        if (pro.Email != null && pro.Email != string.Empty)
                        {
                            Entorno.EliminarInicioSesion(pro.Email, rol);
                        }
                        //y creamos una con el nuevo Email.
                        if (propietario.Email != null && propietario.Email != string.Empty)
                        {
                            Entorno.CrearInicioSesion(propietario.Email, rol);
                        }
                    }
                }

                return RedirectToAction("Index");
            }
            ViewBag.IdProvincia = new SelectList(db.Provincias, "IdProvincia", "Nombre", propietario.IdProvincia);
            ViewBag.IdSubcuenta = new SelectList(db.Subcuentas, "IdSubcuenta", "Descripcion", propietario.IdSubcuenta);
            ViewBag.FormaCobroIdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", propietario.FormaCobroIdFormaCobro);
            return View(propietario);
        }

        //
        // GET: /Propietario/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == id);
            if (propietario == null)
            {
                return HttpNotFound();
            }
            return View(propietario);
        }

        //
        // POST: /Propietario/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            try
            {
                var propiedades = db.PropiedadesPropietarios.Where(p => p.PropietarioIdPersona == id).ToList();

                if (propiedades.Count == 0)
                {
                    Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == id);
                    string email = propietario.Email;
                    db.Personas.DeleteObject(propietario);
                    db.SaveChanges();

                    //Eliminamos el usuario de inicio de sesión
                    if (email != null && email != string.Empty)
                    {
                        Entorno.EliminarInicioSesion(email, rol);
                    }
                }
                else
                {
                    return RedirectToAction("RelatedData", "Error");
                }
            }
            catch (Exception)
            {
                
            }

            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        /// <summary>
        /// Muestra las propiedades de un propietario
        /// </summary>
        /// <param name="id">Id del propietario</param>
        /// <returns></returns>
        public ActionResult Propiedades(int id)
        {
            IEnumerable<PropiedadesPropietario> propiedades = from po in db.Personas
                                                              join pp in db.PropiedadesPropietarios on new { IdPersona = po.IdPersona } equals new { IdPersona = pp.PropietarioIdPersona }
                                                              join pd in db.Propiedades on pp.IdPropiedad equals pd.IdPropiedad
                                                              join co in db.Comunidades on pd.IdComunidad equals co.IdComunidad 
                                                              where
                                                                  po.IdPersona == id
                                                              select new PropiedadesPropietario
                                                              {
                                                                  IdPropiedad = pd.IdPropiedad,
                                                                  Direccion = co.Direccion,
                                                                  Localidad = co.Localidad,
                                                                  Tipo = pd.TipoPropiedad.Tipo,
                                                                  PropiedadDesc = pd.PropiedadDesc,
                                                                  Porcentaje = pp.Porcentaje
                                                              };

            ViewBag.IdPropietario = id;
            Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == id);
            ViewBag.Nombre = propietario.Nombre + " " + propietario.Apellidos;

            return View(propiedades);
        }

        /// <summary>
        /// Redirige a la acción Edit del controlador de Propiedades
        /// </summary>
        /// <param name="id">Id de la propiedad a editar</param>
        /// <returns></returns>
        public ActionResult EditarPropiedad(int idPropiedad)
        {
            return RedirectToAction("Edit", "Propiedades", new { id = idPropiedad });
        }

        public ActionResult DesasignarPropiedad(int idPropiedad, int idPropietario)
        {
            return RedirectToAction("Delete", "PropiedadesPropietarios", new { idPropiedad = idPropiedad, idPropietario = idPropietario });
        }
    }
}