﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using TFC.Helpers;

namespace TFC.Controllers
{
    public class ProvinciasController : BaseController
    {
        private const string MODULO = "DatosMaestros";
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Provincias/

        public ActionResult Index()
        {
            List<MenuItem> items = GetMenu(MODULO);

            ViewBag.MenuItems = items;
            var provincias = db.Provincias.Include("Pais");
            return View(provincias.ToList());
        }

        //
        // GET: /Provincias/Details/5

        public ActionResult Details(int id = 0)
        {
            Provincia provincia = db.Provincias.Single(p => p.IdProvincia == id);
            if (provincia == null)
            {
                return HttpNotFound();
            }
            return View(provincia);
        }

        //
        // GET: /Provincias/Create

        public ActionResult Create()
        {
            ViewBag.IdPais = new SelectList(db.Paises, "IdPais", "Nombre");
            return View();
        }

        //
        // POST: /Provincias/Create

        [HttpPost]
        public ActionResult Create(Provincia provincia)
        {
            if (ModelState.IsValid)
            {
                db.Provincias.AddObject(provincia);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.IdPais = new SelectList(db.Paises, "IdPais", "Nombre", provincia.IdPais);
            return View(provincia);
        }

        //
        // GET: /Provincias/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Provincia provincia = db.Provincias.Single(p => p.IdProvincia == id);
            if (provincia == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdPais = new SelectList(db.Paises, "IdPais", "Nombre", provincia.IdPais);
            return View(provincia);
        }

        //
        // POST: /Provincias/Edit/5

        [HttpPost]
        public ActionResult Edit(Provincia provincia)
        {
            if (ModelState.IsValid)
            {
                db.Provincias.Attach(provincia);
                db.ObjectStateManager.ChangeObjectState(provincia, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdPais = new SelectList(db.Paises, "IdPais", "Nombre", provincia.IdPais);
            return View(provincia);
        }

        //
        // GET: /Provincias/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Provincia provincia = db.Provincias.Single(p => p.IdProvincia == id);
            if (provincia == null)
            {
                return HttpNotFound();
            }
            return View(provincia);
        }

        //
        // POST: /Provincias/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            //Comprobamos si el país a borrar tiene provincias asociadas.
            //Si es así, no se permite la eliminación.
            var comunidades = db.Comunidades.Where(p => p.IdProvincia == id).ToList();
            var personas = db.Personas.Where(p => p.IdProvincia == id).ToList();

            if (comunidades.Count == 0 && personas.Count == 0)
            {
                Provincia provincia = db.Provincias.Single(p => p.IdProvincia == id);
                db.Provincias.DeleteObject(provincia);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            else
            {
                return RedirectToAction("RelatedData", "Error");
            }
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}