﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Models;
using System.Threading;

namespace TFC.Controllers
{
    public class RecibosController : Controller
    {
        private TFCEntities1 db = new TFCEntities1();

        //
        // GET: /Recibos/

        public ActionResult Index()
        {
            IEnumerable<ListaRecibos> recibos = null;
         
            // Si es un administrador de fincas, mostramos las incidencias de las comunidades clientes.
            recibos = from r in db.Recibos.Include("FormasCobro").Include("Propiedad").Include("Propietario")
                            join p in db.Propiedades on r.IdPropiedad equals p.IdPropiedad
                            join c in db.Comunidades on p.IdComunidad equals c.IdComunidad
                            join a in db.Personas on c.AdministradorFincasIdPersona equals a.IdPersona
                            where a.Email == User.Identity.Name
                            select new ListaRecibos
                            {
                                IdRecibo = r.IdRecibo,
                                Comunidad = c.Direccion + " (" + c.Localidad + ")",
                                Fecha = r.Fecha,
                                Propietario = r.Propietario.Nombre + " " + r.Propietario.Apellidos,
                                Propiedad = r.Propiedad.PropiedadDesc,
                                Concepto = r.Concepto,
                                FormaCobro = r.FormasCobro.FormaCobroDesc,
                                Importe = r.Importe
                            };

            return View(recibos.ToList());
        }

        //
        // GET: /Recibos/Create

        public ActionResult Create()
        {
            this.GetComunidades();
            ViewBag.IdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc");
            ViewBag.PropietarioIdPersona = new SelectList(new List<string>(), "IdPersona", "Nombre");
            ViewBag.IdPropiedad = new SelectList(new List<string>(), "IdPropiedad", "PropiedadDesc");
            return View();
        }

        //
        // POST: /Recibos/Create

        [HttpPost]
        public ActionResult Create(Recibo recibo)
        {
            if (ModelState.IsValid)
            {
                db.Recibos.AddObject(recibo);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            this.GetComunidades();
            ViewBag.IdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", recibo.IdFormaCobro);
            ViewBag.PropietarioIdPersona = new SelectList(new List<string>(), "IdPersona", "Nombre");
            ViewBag.IdPropiedad = new SelectList(new List<string>(), "IdPropiedad", "PropiedadDesc");
            return View(recibo);
        }

        public ActionResult CreateMasivo()
        {
            // Obtenemos los tipos de períodos
            ViewBag.IdTipoPeriodo = new SelectList(db.TiposPeriodo, "IdTipoPeriodo", "Descripcion");
            //No mostramos ninguna comunidad porque se mostrarán cuando el usuario seleccione un tipo de período.
            ViewBag.Comunidades = new List<string>();
            RecibosMasivos rm = new RecibosMasivos();

            return View(rm);
        }

        //
        // POST: /Recibos/Create

        [HttpPost]
        public ActionResult CreateMasivo(RecibosMasivos recibos)
        {
            if (ModelState.IsValid)
            {
                //Recorremos las comunidades seleccionadas y creamos un recibo para cada propietario.
                foreach (int idComunidad in recibos.Comunidades)
                {
                    //Obtenemos las propiedades de la comunidad
                    IList<Propiedad> propiedades = Datos.GetPropiedades(idComunidad);

                    if (propiedades != null && propiedades.Count > 0)
                    { 
                        //Recorremos las propiedades para obtener los propietarios.
                        foreach (Propiedad propiedad in propiedades)
                        {
                            IList<Propietario> propietarios = Datos.GetPropietariosPropiedad(propiedad.IdPropiedad);

                            if (propietarios != null && propietarios.Count > 0) { 
                                //Recorremos los propietarios y creamos un recibo por cada uno de ellos.
                                foreach (Propietario prop in propietarios)
                                {
                                    Propietario propietario = db.Personas.OfType<Propietario>().Single(p => p.IdPersona == prop.IdPersona);
                                    Recibo recibo = new Recibo();
                                    recibo.Fecha = recibos.Fecha;
                                    recibo.Concepto = recibos.Concepto;
                                    recibo.IdPropiedad = propiedad.IdPropiedad;
                                    recibo.PropietarioIdPersona = propietario.IdPersona;
                                    recibo.IdFormaCobro = (int) propietario.FormaCobroIdFormaCobro;

                                    //El importe del recibo se calcula a partir de la cuota de la propiedad 
                                    //y el porcentaje de la propiedad que tiene cada propietario.
                                    PropiedadPropietario pp = db.PropiedadesPropietarios.Where(p => p.IdPropiedad == propiedad.IdPropiedad 
                                        && p.PropietarioIdPersona == propietario.IdPersona).FirstOrDefault();

                                    if (pp != null && (double)propiedad.Cuota > 0 && pp.Porcentaje > 0 )
                                    {
                                        recibo.Importe = Math.Round((double)propiedad.Cuota * pp.Porcentaje / 100, 2);

                                        db.Recibos.AddObject(recibo);
                                    }
                                }
                            }                       
                        }
                    }
                }
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            
            return View(recibos);
        }

        //
        // GET: /Recibos/Edit/5

        public ActionResult Edit(int id = 0)
        {
            Recibo recibo = db.Recibos.Single(r => r.IdRecibo == id);
            if (recibo == null)
            {
                return HttpNotFound();
            }
            ViewBag.IdAsiento = new SelectList(db.Asientos, "IdAsiento", "IdAsiento", recibo.IdAsiento);
            ViewBag.IdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", recibo.IdFormaCobro);
            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", recibo.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", recibo.PropietarioIdPersona);
            return View(recibo);
        }

        //
        // POST: /Recibos/Edit/5

        [HttpPost]
        public ActionResult Edit(Recibo recibo)
        {
            if (ModelState.IsValid)
            {
                db.Recibos.Attach(recibo);
                db.ObjectStateManager.ChangeObjectState(recibo, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.IdAsiento = new SelectList(db.Asientos, "IdAsiento", "IdAsiento", recibo.IdAsiento);
            ViewBag.IdFormaCobro = new SelectList(db.FormasCobro, "IdFormaCobro", "FormaCobroDesc", recibo.IdFormaCobro);
            ViewBag.IdPropiedad = new SelectList(db.Propiedades, "IdPropiedad", "PropiedadDesc", recibo.IdPropiedad);
            ViewBag.PropietarioIdPersona = new SelectList(db.Personas, "IdPersona", "Nombre", recibo.PropietarioIdPersona);
            return View(recibo);
        }

        //
        // GET: /Recibos/Delete/5

        public ActionResult Delete(int id = 0)
        {
            Recibo recibo = db.Recibos.Single(r => r.IdRecibo == id);
            if (recibo == null)
            {
                return HttpNotFound();
            }
            return View(recibo);
        }

        //
        // POST: /Recibos/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Recibo recibo = db.Recibos.Single(r => r.IdRecibo == id);
            db.Recibos.DeleteObject(recibo);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }

        private void GetComunidades(int idComunidad = 0)
        {
            // Obtenemos las comunidades a las que tiene acceso el usuario conectado.
            IList<Comunidad> listaComunidades = Datos.GetComunidades(User.Identity.Name);
            var comunidades = from c in listaComunidades
                              orderby c.Localidad, c.Direccion
                              select new
                              {
                                  IdComunidad = c.IdComunidad,
                                  Direccion = c.Direccion + " (" + c.Localidad + ")"
                              };

            if (idComunidad > 0)
            {
                //Si el parámetro opcional idComunidad tiene valor, se lo asociamos a la lista como valor seleccionado por defecto.
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion", idComunidad);
            }
            else
            {
                ViewBag.IdComunidad = new SelectList(comunidades, "IdComunidad", "Direccion");
            }
        }

        [HttpPost]
        public ActionResult GetPropiedades(int idComunidad)
        {
            IEnumerable<Propiedad> propiedades = Datos.GetPropiedades(idComunidad);
            if (propiedades != null)
            {
                var prop = from p in propiedades
                           select new
                           {
                               IdPropiedad = p.IdPropiedad.ToString(),
                               PropiedadDesc = p.TipoPropiedad.Tipo + " " + p.PropiedadDesc
                           };

                Thread.Sleep(1000); // Simulamos tiempo de proceso...

                return Json(new SelectList(prop, "IdPropiedad", "PropiedadDesc"));
            }
            else
            {
                return Json(new SelectList(new List<string>(), "IdPropiedad", "PropiedadDesc"));
            }
            
        }

        [HttpPost]
        public ActionResult GetPropietarios(int idPropiedad)
        {
            IEnumerable<Propietario> propietarios = Datos.GetPropietariosPropiedad(idPropiedad);

            if (propietarios != null)
            {
                var prop = from p in propietarios
                           select new
                           {
                               IdPersona = p.IdPersona.ToString(),
                               Nombre = p.Nombre + " " + p.Apellidos
                           };

                Thread.Sleep(1000); // Simulamos tiempo de proceso...

                return Json(new SelectList(prop, "IdPersona", "Nombre"));
            }
            else
            {
                return Json(new SelectList(new List<string>(), "IdPersona", "Nombre"));
            }
            
        }

        [HttpPost]
        public ActionResult GetComunidadesPorTipoPeriodo(int idTipo)
        {
            //Obtenemos las comunidades del usuario
            IList<Comunidad> comunidades = Datos.GetComunidades(User.Identity.Name);

            //Filtramos las del tipo de período seleccionado
            var com = from c in comunidades
                      where c.IdTipoPeriodo == idTipo 
                      orderby c.Localidad, c.Direccion
                      select new
                      {
                          IdComunidad = c.IdComunidad,
                          Direccion = c.Direccion + " (" + c.Localidad + ")"
                      };

            if (com != null)
            {
                return Json(new MultiSelectList(com, "IdComunidad", "Direccion"));
            }
            else
            {
                return Json(new MultiSelectList(new List<string>(), "IdComunidad", "Direccion"));
            }
        }

    }
}