﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using TFC.Filters;
using TFC.Helpers;

namespace TFC.Controllers
{
    /// <summary>
    /// Controlador de la barra de menú lateral o sidebar.
    /// Cada vez que el usuario hace clic en un elemento del menú superior o principal,
    /// se produce una llamada a este controlador para mostrar las diferentes opciones 
    /// del menú seleccionado.
    /// </summary>
    public class SidebarController : BaseController
    {
        //
        // GET: /Sidebar/

        public ActionResult Index()
        {
            return View();
        }

        /// <summary>
        /// Método que devuelve la vista de las opciones del menú o módulo "Datos Maestros".
        /// </summary>
        /// <returns></returns>
        public ActionResult DatosMaestros()
        {
            // La variable de sesión Sidebar tiene siempre guardado el último menú lateral mostrado,
            // en formato html (cargado desde la vista parcial Views/Shared/_Sidebar.cshtml). Esta variable
            // se utiliza para mejorar el rendimiento, es decir, para no tener que estar buscando los mismos 
            // elementos una y otra vez de un mismo menú principal o módulo.
            // Cada vez que se hace clic en un elemento del menú principal, restablecemos a null la variable
            // de sesión Sidebar para que se vuelva a cargar el menú lateral correspondiente. 
            Session["Sidebar"] = null;

            // Obtenemos las opciones del menú "Datos Maestros" a través del método GetMenu heredado de BaseController.
            List<MenuItem> items = GetMenu("DatosMaestros");

            ViewBag.MenuItems = items;

            return View();
        }

        /// <summary>
        /// Método que devuelve la vista de las opciones del menú o módulo "Comunicaciones".
        /// </summary>
        /// <returns></returns>
        public ActionResult Comunicaciones()
        {
            Session["Sidebar"] = null;
            List<MenuItem> items = GetMenu("Comunicaciones");

            ViewBag.MenuItems = items;

            return View();
        }

        /// <summary>
        /// Método que devuelve la vista de las opciones del menú o módulo "Contabilidad".
        /// </summary>
        /// <returns></returns>
        public ActionResult Contabilidad()
        {
            Session["Sidebar"] = null;
            List<MenuItem> items = GetMenu("Contabilidad");

            ViewBag.MenuItems = items;

            return View();
        }

        /// <summary>
        /// Método que devuelve la vista de las opciones del menú o módulo "Informes".
        /// </summary>
        /// <returns></returns>
        public ActionResult Informes()
        {
            Session["Sidebar"] = null;
            List<MenuItem> items = GetMenu("Informes");

            ViewBag.MenuItems = items;

            return View();
        }

        /// <summary>
        /// Método que devuelve la vista de las opciones del menú o módulo "Configuración".
        /// </summary>
        /// <returns></returns>
        public ActionResult Configuracion()
        {
            Session["Sidebar"] = null;
            List<MenuItem> items = GetMenu("Configuracion");

            ViewBag.MenuItems = items;

            return View();
        }
    }
}
