﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using TFC.Models;
using System.Web.Mvc;
using System.Reflection;

namespace TFC.Helpers
{
    public static class Util
    {
        private static TFCEntities1 db = new TFCEntities1();

        /// <summary>
        /// Comprueba si la persona tiene un cargo en la comunidad en cuestión.
        /// </summary>
        /// <param name="idComunidad"></param>
        /// <param name="idPersona"></param>
        /// <returns></returns>
        public static bool conCargo(int idComunidad, int idPersona)
        {
            DateTime hoy = DateTime.Now.Date;

            var query = from ec in db.EjerciciosCargo
                        where ec.IdComunidad == idComunidad &&
                            ec.PropietarioIdPersona == idPersona &&
                          hoy >= ec.FechaInicio && hoy <= ec.FechaFin
                        select new
                        {
                            ec.IdEjercicio
                        };

            if (query.ToList().Count > 0)
            {
                return true;
            }
            else
            {
                return false;
            }

        }

        public class FileUploadJsonResult : JsonResult
        {
            public override void ExecuteResult(ControllerContext context)
            {
                this.ContentType = "text/html";
                context.HttpContext.Response.Write("<textarea>");
                base.ExecuteResult(context);
                context.HttpContext.Response.Write("</textarea>");
            }

        }

        /// <summary>
        /// Envía un correo electrónico 
        /// </summary>
        /// <param name="asunto"></param>
        /// <param name="texto"></param>
        /// <param name="destinatarios">Direcciones de correo de los destinatarios</param>
        public static void EnviarEmail (string asunto, string texto, IList<string> destinatarios)
        {
	        try {

                if(destinatarios != null) 
                {
                    if (destinatarios.Count > 0)
                    {
                        string ServidorSMTP = db.Parametros.Single(p => p.Clave == "smtp_server").Valor;
                        string User = db.Parametros.Single(p => p.Clave == "smtp_user").Valor;
                        string Pass = db.Parametros.Single(p => p.Clave == "smtp_pass").Valor;
                        string Remitente = db.Parametros.Single(p => p.Clave == "smtp_remite").Valor;
                        string DirRemitente = db.Parametros.Single(p => p.Clave == "smtp_dirRemite").Valor;
                        int Port = int.Parse(db.Parametros.Single(p => p.Clave == "smtp_port").Valor);

                        //Configuracion del servidor de correo
                        System.Net.Mail.SmtpClient Servidor = new System.Net.Mail.SmtpClient();

                        Servidor.Host = ServidorSMTP;
                        Servidor.Port = Port;
                        Servidor.Credentials = new System.Net.NetworkCredential(User, Pass);

                        System.Net.Mail.MailMessage mail = new System.Net.Mail.MailMessage();

                        mail.From = new System.Net.Mail.MailAddress(DirRemitente, Remitente);

                        mail.Subject = asunto;
                        mail.SubjectEncoding = System.Text.Encoding.UTF8;
                        mail.Body = texto;
                        mail.BodyEncoding = System.Text.Encoding.UTF8;
                        mail.IsBodyHtml = true;

                        int i = 0;
                        foreach (string dest in destinatarios)
                        {
                            if (i == 0)
                            {
                                mail.To.Add(dest);
                                i = 1;
                            }
                            else
                            {
                                //Enviamos el correo en copia oculta para que los destinatarios  
                                //no puedan ver las direcciones de correo de los demás.
                                mail.Bcc.Add(new System.Net.Mail.MailAddress(dest));
                            }
                        }

                        Servidor.Send(mail);
                    }
                }
			}
	        catch (Exception ex) {
                throw ex;
	        }
        }
    }
}