﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ComponentModel.DataAnnotations;
using TFC.Filters;
using TFC.Helpers;

namespace TFC.Models
{
    
    #region Incidencias

    [MetadataType(typeof(IncidenciaMetadata))]
    public partial class Incidencia
    {
        public int IdComunidad { get; set; }
    }

    public class IncidenciaMetadata
    {
        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Comunidad", typeof(TFC.Resources.Models.Incidencia))]
        public int IdComunidad { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Texto", typeof(TFC.Resources.Models.Incidencia))]
        public string Texto { get; set; }

        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [LocalizationDisplayName("Persona", typeof(TFC.Resources.Models.Incidencia))]
        public int IdPersona { get; set; }

        [LocalizationDisplayName("Categoria", typeof(TFC.Resources.Models.Incidencia))]
        public int IdCategoria { get; set; }

        [LocalizationDisplayName("Estado", typeof(TFC.Resources.Models.Incidencia))]
        public int IdEstado { get; set; }

        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Incidencia))]
        public DateTime Fecha { get; set; }  
    }
   
    public class ListaIncidencias
    {
        [Display(Name = "Nº Incid.")]
        public int IdComunicacion { get; set; }

        [Display(Name = "IdComunidad")]
        public int IdComunidad { get; set; }

        [Display(Name = "Comunidad")]
        public string ComunidadDesc { get; set; }

        [Display(Name = "Fecha")]
        public DateTime Fecha { get; set; }

        [Display(Name = "Persona")]
        public string Persona { get; set; }

        [Display(Name = "Propiedad")]
        public string PropiedadDesc { get; set; }

        [Display(Name = "Categoría")]
        public string Categoria { get; set; }

        [Display(Name = "Estado")]
        public string Estado { get; set; }

        [Display(Name = "Texto")]
        public string Texto { get; set; }
    }
#endregion

    #region Noticias
    
    [MetadataType(typeof(NoticiaMetadata))]
    public partial class Noticia
    {
    }

    public class NoticiaMetadata
    {
        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Titulo", typeof(TFC.Resources.Models.Noticia))]
        public string Titulo { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Texto", typeof(TFC.Resources.Models.Noticia))]
        public string Texto { get; set; }

        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [LocalizationDisplayName("Persona", typeof(TFC.Resources.Models.Noticia))]
        public int IdPersona { get; set; }

        [LocalizationDisplayName("Categoria", typeof(TFC.Resources.Models.Noticia))]
        public int IdCategoria { get; set; }

        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Noticia))]
        public DateTime Fecha { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaInicio", typeof(TFC.Resources.Models.Noticia))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaInicio { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaFin", typeof(TFC.Resources.Models.Noticia))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaFin { get; set; }

        [LocalizationDisplayName("Url", typeof(TFC.Resources.Models.Noticia))]
        public string Url { get; set; }

        [LocalizationDisplayName("TextoUrl", typeof(TFC.Resources.Models.Noticia))]
        public string TextoUrl { get; set; }

    }
  
#endregion

    #region Anuncios

    [MetadataType(typeof(AnuncioMetadata))]
    public partial class Anuncio
    {
    }

    public class AnuncioMetadata
    {
        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Titulo", typeof(TFC.Resources.Models.Anuncio))]
        public string Titulo { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Texto", typeof(TFC.Resources.Models.Anuncio))]
        public string Texto { get; set; }

        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [LocalizationDisplayName("Persona", typeof(TFC.Resources.Models.Anuncio))]
        public int IdPersona { get; set; }

        [LocalizationDisplayName("Categoria", typeof(TFC.Resources.Models.Anuncio))]
        public int IdCategoria { get; set; }

        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Anuncio))]
        public DateTime Fecha { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaInicio", typeof(TFC.Resources.Models.Anuncio))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaInicio { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaFin", typeof(TFC.Resources.Models.Anuncio))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaFin { get; set; }
    }

    #endregion

    #region Sugerencias

    [MetadataType(typeof(SugerenciaMetadata))]
    public partial class Sugerencia
    {
        public int IdComunidad { get; set; }
    }

    public class SugerenciaMetadata
    {
        [Required(ErrorMessageResourceName = "ErrorRequiredComunidad",
                    ErrorMessageResourceType = typeof(TFC.Resources.Models.Sugerencia))]
        [LocalizationDisplayName("Comunidad", typeof(TFC.Resources.Models.Sugerencia))]
        public int IdComunidad { get; set; }

        [Required(ErrorMessageResourceName = "ErrorRequiredTexto",
                    ErrorMessageResourceType = typeof(TFC.Resources.Models.Sugerencia))]
        [LocalizationDisplayName("Texto", typeof(TFC.Resources.Models.Sugerencia))]
        public string Texto { get; set; }

        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [LocalizationDisplayName("Persona", typeof(TFC.Resources.Models.Sugerencia))]
        public int IdPersona { get; set; }

        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Sugerencia))]
        public DateTime Fecha { get; set; }
    }

    public class ListaSugerencias
    {
        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [Display(Name = "Comunidad")]
        public string ComunidadDesc { get; set; }

        [Display(Name = "Fecha")]
        public DateTime Fecha { get; set; }

        [Display(Name = "Persona")]
        public string Persona { get; set; }

        [Display(Name = "Propiedad")]
        public string PropiedadDesc { get; set; }

        [Display(Name = "Texto")]
        public string Texto { get; set; }

        [Display(Name = "Email")]
        public string Email { get; set; }

        [Display(Name = "IdComunidad")]
        public int IdComunidad { get; set; }
    }

#endregion

    #region Fichero

    [MetadataType(typeof(FicheroMetadata))]
    public partial class Fichero
    {
        public string Icono
        {
            get
            {
                string extension = this.NombreFichero.Substring(this.NombreFichero.Length - 4).ToLower();
                if (extension == ".xls" || extension == "xlsx")
                {
                    return "file_excel.png";
                }
                else if (extension == ".doc" || extension == "docx")
                {
                    return "file_word.png";
                }
                else if (extension == ".jpg" || extension == ".png" || extension == ".gif" || extension == ".bmp"){
                    return "file_image.png";
                }
                else if (extension == ".pdf")
                {
                    return "file_pdf.png";
                }
                else if (extension == ".ppt" || extension == ".pps" || extension == "pptx" || extension == "ppsx")
                {
                    return "file_pps.png";
                }
                else if (extension == ".zip" || extension == ".rar")
                {
                    return "file_zip.png";
                }
                else
                {
                    return "file_default.png";
                }
            }
        }
    }

    public class FicheroMetadata
    {
        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Titulo", typeof(TFC.Resources.Models.Fichero))]
        public string Titulo { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Texto", typeof(TFC.Resources.Models.Fichero))]
        public string Texto { get; set; }

        [Display(Name = "IdComunicacion")]
        public int IdComunicacion { get; set; }

        [LocalizationDisplayName("Persona", typeof(TFC.Resources.Models.Fichero))]
        public int IdPersona { get; set; }

        [LocalizationDisplayName("Categoria", typeof(TFC.Resources.Models.Fichero))]
        public int IdCategoria { get; set; }

        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Fichero))]
        public DateTime Fecha { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaInicio", typeof(TFC.Resources.Models.Fichero))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaInicio { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FechaFin", typeof(TFC.Resources.Models.Fichero))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        public DateTime FechaFin { get; set; }

    }

    #endregion

    #region ComunicacionesComunidades

    public class ComunicacionComunidades
    {
        public int IdComunicacion { get; set; }

        public ICollection<int> Comunidades { get; set; }

        public ComunicacionComunidades()
        {
            Comunidades = new List<int>();
        }
        public ComunicacionComunidades(int idComunicacion)
        {
            IdComunicacion = idComunicacion;
            Comunidades = new List<int>();
        }
    }

    #endregion

    [MetadataType(typeof(CategoriaMetadata))]
    public partial class Categoria
    {
        
    }

    public class CategoriaMetadata
    {

        [LocalizationDisplayName("CategoriaDesc", typeof(TFC.Resources.Models.Categoria))]
        public string Descripcion { get; set; }

    }
}