﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ComponentModel.DataAnnotations;
using TFC.Filters;
using TFC.Helpers;

namespace TFC.Models
{
    
    #region Recibos

    [MetadataType(typeof(ReciboMetadata))]
    public partial class Recibo
    {
        public int IdComunidad { get; set; }
    }

    public class ReciboMetadata
    {
        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Comunidad", typeof(TFC.Resources.Models.Recibo))]
        public int IdComunidad { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Propiedad", typeof(TFC.Resources.Models.Recibo))]
        public int IdPropiedad { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Propietario", typeof(TFC.Resources.Models.Recibo))]
        public int PropietarioIdPersona { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Concepto", typeof(TFC.Resources.Models.Recibo))]
        public string Concepto { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("FormasCobro", typeof(TFC.Resources.Models.Recibo))]
        public int IdFormaCobro { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Recibo))]
        public DateTime Fecha { get; set; }  
    }

    public class ListaRecibos
    {
        [Display(Name = "IdRecibo")]
        public int IdRecibo { get; set; }

        [Display(Name = "Comunidad")]
        public string Comunidad { get; set; }

        [Display(Name = "Fecha")]
        public DateTime Fecha { get; set; }

        [Display(Name = "Propietario")]
        public string Propietario { get; set; }

        [Display(Name = "Propiedad")]
        public string Propiedad { get; set; }

        [Display(Name = "Concepto")]
        public string Concepto { get; set; }

        [Display(Name = "FormasCobro")]
        public string FormaCobro { get; set; }

        [Display(Name = "Importe")]
        public double Importe { get; set; }
    }

    #region RecibosMasivos

    public class RecibosMasivos
    {
        /// <summary>
        /// Constructor sin parámetros
        /// </summary>
        public RecibosMasivos()
        {
            Comunidades = new List<int>();
        }

        [LocalizationDisplayName("Comunidades", typeof(TFC.Resources.Models.Recibo))]
        public ICollection<int> Comunidades { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [DataType(DataType.Date, ErrorMessageResourceName = "FechaInvalida",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Fecha", typeof(TFC.Resources.Models.Recibo))]
        public DateTime Fecha { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("Concepto", typeof(TFC.Resources.Models.Recibo))]
        public string Concepto { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("IdTipoPeriodo", typeof(TFC.Resources.Models.Recibo))]
        public int IdTipoPeriodo { get; set; }

        [Required(ErrorMessageResourceName = "Requerido",
                    ErrorMessageResourceType = typeof(TFC.Resources.Shared.Error))]
        [LocalizationDisplayName("NumPeriodos", typeof(TFC.Resources.Models.Recibo))]
        public int NumPeriodos { get; set; }
    }
    #endregion

#endregion

}