﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using WebMatrix.WebData;
using System.Web.Security;

namespace TFC.Models
{
    #region Entorno

    public static class Entorno
    {
        private static TFCEntities1 db = new TFCEntities1();
 
        public static Persona PersonaConectada(string email)
        {
            return db.Personas.Single(p => p.Email == email);
        }

        /// <summary>
        /// Crea una cuenta de inicio de sesión en la aplicación con la contraseña por defecto.
        /// </summary>
        /// <param name="email"></param>
        /// <param name="rol"></param>
        public static void CrearInicioSesion(string email, string rol)
        {
            if (!WebSecurity.UserExists(email))
            {
                string password = db.Parametros.Where(p => p.Clave == "default_pass").Single().Valor;
                WebSecurity.CreateUserAndAccount(email, password);
                Roles.AddUsersToRoles(new[] { email }, new[] { rol });
            }   
        }

        /// <summary>
        /// Elimina una cuenta de inicio de sesión y todos los datos del perfil asociado con ella.
        /// </summary>
        /// <param name="email"></param>
        public static void EliminarInicioSesion(string email, string rol)
        {
            if (WebSecurity.UserExists(email)) 
            { 
                if (Roles.IsUserInRole(email, rol))
                {
                    Roles.RemoveUserFromRole(email, rol);
                }
                Membership.DeleteUser(email, true);
            }
        }
    }

    #endregion

    #region Obtencion de datos

    public static class Datos
    {
        private static TFCEntities1 db = new TFCEntities1();

        /// <summary>
        /// Obtiene todas las comunidades relacionadas con una persona
        /// </summary>
        /// <param name="persona"></param>
        /// <returns></returns>
        public static IList<Comunidad> GetComunidades(Persona persona)
        {
            List<Comunidad> comunidades = null;

            if (persona is AdministradorFincas)
            {
                comunidades = (from c in db.Comunidades
                               where c.AdministradorFincasIdPersona == persona.IdPersona
                               orderby c.Direccion
                               select c).ToList();
            }
            else if (persona is Propietario)
            {
                comunidades = (from c in db.Comunidades
                               join p in db.Propiedades on c.IdComunidad equals p.IdComunidad
                               join pp in db.PropiedadesPropietarios on p.IdPropiedad equals pp.IdPropiedad
                               join po in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals po.IdPersona
                               where po.IdPersona == persona.IdPersona
                               orderby c.Direccion
                               select c).ToList();
            }

            return comunidades;
        }

        public static IList<Comunidad> GetComunidades(string email)
        {
            return GetComunidades(db.Personas.Single(p => p.Email == email));
        }

        /// <summary>
        /// Obtiene los propietarios de una comunidad
        /// </summary>
        /// <param name="idComunidad"></param>
        /// <returns></returns>
        public static IList<Propietario> GetPropietarios(int idComunidad)
        {
            List<Propietario> propietarios = (from p in db.Propiedades 
                                              join pp in db.PropiedadesPropietarios on p.IdPropiedad equals pp.IdPropiedad
                                              join po in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals po.IdPersona
                                              where p.IdComunidad == idComunidad 
                                              orderby po.Nombre, po.Apellidos
                                              select po).ToList();
            if (propietarios.Count == 0)
            {
                return null;
            }
            else
            {
                return propietarios;
            }
        }

        /// <summary>
        /// Obtiene las propiedades de una comunidad
        /// </summary>
        /// <param name="idComunidad"></param>
        /// <returns></returns>
        public static IList<Propiedad> GetPropiedades(int idComunidad)
        {
            List<Propiedad> propiedades = (from p in db.Propiedades
                                              where p.IdComunidad == idComunidad
                                              orderby p.PropiedadDesc
                                              select p).ToList();
            if (propiedades.Count == 0)
            {
                return null;
            }
            else
            {
                return propiedades;
            }
        }

        /// <summary>
        /// Obtiene los propietarios de una propiedad
        /// </summary>
        /// <param name="idPropiedad"></param>
        /// <returns></returns>
        public static IList<Propietario> GetPropietariosPropiedad(int idPropiedad)
        {
            List<Propietario> propietarios = (from pp in db.PropiedadesPropietarios 
                                              join po in db.Personas.OfType<Propietario>() on pp.PropietarioIdPersona equals po.IdPersona
                                              where pp.IdPropiedad == idPropiedad
                                              orderby po.Nombre, po.Apellidos
                                              select po).ToList();
            if (propietarios.Count == 0)
            {
                return null;
            }
            else
            {
                return propietarios;
            }
        }
    }

    #endregion
}